# This file is automatically generated by generate.py using api.json

class _Projects:
    def __init__(self, client=None):
        self.client = client

    def create(self, params={}, **options):
        """Dispatches a POST request to /projects of the API to create a new project."""
        return self.client.post('/projects', params, **options)

    def update(self, project_id, params={}, **options):
        """Dispatches a PUT request to /projects/:projectId to update the project."""
        path = '/projects/%d' % (project_id)
        return self.client.put(path, params, **options)

    def find_by_id(self, project_id, params={}, **options):
        """Dispatches a GET request to /projects/:projectId of the API to get information about the project."""
        path = '/projects/%d' % (project_id)
        return self.client.get(path, params, **options)

    def find_by_workspace(self, workspace_id, params={}, **options):
        """Dispatches a GET request to /workspaces/:workspaceId/projects to get all the projects associated with the workspace."""
        path = '/workspaces/%d/projects' % (workspace_id)
        return self.client.get_collection(path, params, **options)

    def find_all(self, params={}, **options):
        """Dispatches a GET request to /projects of the API to get information about all projects that the dispatcher as access to."""
        return self.client.get_collection('/projects', params, **options)

    def create_in_workspace(self, workspace_id, params={}, **options):
        """Dispatches a POST request to /workspaces/:workspaceId/projects of the API to create a new project within the workspace."""
        path = '/workspaces/%d/projects' % (workspace_id)
        return self.client.post(path, params, **options)

    def delete(self, project_id, params={}, **options):
        """Dispatches a DELETE requte to /projects/:projectId to delete the project."""
        path = '/projects/%d' % (project_id)
        return self.client.delete(path, params, **options)



# This file is automatically generated by generate.py using api.json

class _Teams:
    def __init__(self, client=None):
        self.client = client

    def find_by_organization(self, organization_id, params={}, **options):
        """Finds all teams that the user has access to."""
        path = '/organizations/%d/teams' % (organization_id)
        return self.client.get_collection(path, params, **options)




from ._events import _Events
from ..error import InvalidTokenError
from ..page_iterator import EventsPageIterator

import time

class Events(_Events):

    def get_next(self, query, **options):
        iterator = EventsPageIterator(self.client, '/events', query, options)
        result = iterator.next()
        return (result, iterator.sync)

    def get_iterator(self, query, **options):
        return EventsPageIterator(self.client, '/events', query, options).items()



# This file is automatically generated by generate.py using api.json

class _Users:
    def __init__(self, client=None):
        self.client = client

    def me(self, params={}, **options):
        """Returns the current user of the dispatcher."""
        return self.client.get('/users/me', params, **options)

    def find_by_workspace(self, workspace_id, params={}, **options):
        """Finds a user by workspace."""
        path = '/workspaces/%d/users' % (workspace_id)
        return self.client.get_collection(path, params, **options)

    def find_all(self, params={}, **options):
        """Returns all users that the dispatcher has access to."""
        return self.client.get_collection('/users', params, **options)

    def find_by_id(self, user_id, params={}, **options):
        """Finds a user by id."""
        path = '/users/%d' % (user_id)
        return self.client.get(path, params, **options)



# This file is automatically generated by generate.py using api.json

class _Workspaces:
    def __init__(self, client=None):
        self.client = client

    def typeahead(self, workspace_id, params={}, **options):
        """Dispatches a GET request to /workspaces/:workspaceId/typeahead to run a typeahead search in the specified workspace."""
        path = '/workspaces/%d/typeahead' % (workspace_id)
        return self.client.get_collection(path, params, **options)

    def find_all(self, params={}, **options):
        """Show all available workspaces."""
        return self.client.get_collection('/workspaces', params, **options)

    def update(self, workspace_id, params={}, **options):
        """Update a workspace."""
        path = '/workspaces/%d' % (workspace_id)
        return self.client.put(path, params, **options)



# This file is automatically generated by generate.py using api.json

class _Stories:
    def __init__(self, client=None):
        self.client = client

    def find_by_task(self, task_id, params={}, **options):
        """Returns the stories on a task."""
        path = '/tasks/%d/stories' % (task_id)
        return self.client.get_collection(path, params, **options)

    def create_on_task(self, task_id, params={}, **options):
        """Creates a story on the task."""
        path = '/tasks/%d/stories' % (task_id)
        return self.client.post(path, params, **options)

    def find_by_id(self, story_id, params={}, **options):
        """Returns the story."""
        path = '/stories/%d' % (story_id)
        return self.client.get(path, params, **options)



# This file is automatically generated by generate.py using api.json

class _Events:
    def __init__(self, client=None):
        self.client = client

    def get(self, params={}, **options):
        """Dispatches a GET request to /events of the API to get a set of recent changes to a resource."""
        options = self.client._merge_options({u'full_payload': True})
        return self.client.get('/events', params, **options)



# This file is automatically generated by generate.py using api.json

class _Tags:
    def __init__(self, client=None):
        self.client = client

    def create(self, params={}, **options):
        """Creates a new tag."""
        return self.client.post('/tags', params, **options)

    def update(self, tag_id, params={}, **options):
        """Update a tag."""
        path = '/tags/%d' % (tag_id)
        return self.client.put(path, params, **options)

    def find_by_id(self, tag_id, params={}, **options):
        """Returns the tag."""
        path = '/tags/%d' % (tag_id)
        return self.client.get(path, params, **options)

    def find_by_workspace(self, workspace_id, params={}, **options):
        """Finds a tag by workspace."""
        path = '/workspaces/%d/tags' % (workspace_id)
        return self.client.get_collection(path, params, **options)

    def find_all(self, params={}, **options):
        """Returns all tags that the dispatcher has access to."""
        return self.client.get_collection('/tags', params, **options)

    def create_in_workspace(self, workspace_id, params={}, **options):
        """Creates a new tag in the workspace."""
        path = '/workspaces/%d/tags' % (workspace_id)
        return self.client.post(path, params, **options)



# This file is automatically generated by generate.py using api.json

class _Attachments:
    def __init__(self, client=None):
        self.client = client

    def find_by_task(self, task_id, params={}, **options):
        """Dispatches a GET request to /tasks/:taskId/attachments of the API to get all attachments associated with the task."""
        path = '/tasks/%d/attachments' % (task_id)
        return self.client.get_collection(path, params, **options)

    def find_by_id(self, attachment_id, params={}, **options):
        """Dispatches a GET request to /attachments/:attachmentId of the API to get information about the attachment."""
        path = '/attachments/%d' % (attachment_id)
        return self.client.get(path, params, **options)



# This file is automatically generated by generate.py using api.json

class _Tasks:
    def __init__(self, client=None):
        self.client = client

    def add_followers(self, task_id, params={}, **options):
        """Dispatches a POST request to /tasks/:taskId/addFollowers with to add followers to the task."""
        path = '/tasks/%d/addFollowers' % (task_id)
        return self.client.post(path, params, **options)

    def find_by_tag(self, tag_id, params={}, **options):
        """Finds a task by tag."""
        path = '/tags/%d/tasks' % (tag_id)
        return self.client.get_collection(path, params, **options)

    def tags(self, task_id, params={}, **options):
        """Get tags associated with a task."""
        path = '/tasks/%d/tags' % (task_id)
        return self.client.get_collection(path, params, **options)

    def add_project(self, task_id, params={}, **options):
        """Dispatches a POST request to /tasks/:taskId/addProject with the project to add to to the task."""
        path = '/tasks/%d/addProject' % (task_id)
        return self.client.post(path, params, **options)

    def create(self, params={}, **options):
        """Creates a new task."""
        return self.client.post('/tasks', params, **options)

    def remove_tag(self, task_id, params={}, **options):
        """Dispatches a POST request to /tasks/:taskId/removeTag with the tag to remove from the task."""
        path = '/tasks/%d/removeTag' % (task_id)
        return self.client.post(path, params, **options)

    def update(self, task_id, params={}, **options):
        """Update a task."""
        path = '/tasks/%d' % (task_id)
        return self.client.put(path, params, **options)

    def find_by_project(self, project_id, params={}, **options):
        """Finds a task by project."""
        path = '/projects/%d/tasks' % (project_id)
        return self.client.get_collection(path, params, **options)

    def find_by_id(self, task_id, params={}, **options):
        """Returns the task."""
        path = '/tasks/%d' % (task_id)
        return self.client.get(path, params, **options)

    def subtasks(self, task_id, params={}, **options):
        """Gets all subtasks for a task."""
        path = '/tasks/%d/subtasks' % (task_id)
        return self.client.get_collection(path, params, **options)

    def add_subtask(self, task_id, params={}, **options):
        """Creates a new subtask."""
        path = '/tasks/%d/subtasks' % (task_id)
        return self.client.post(path, params, **options)

    def add_tag(self, task_id, params={}, **options):
        """Add a tag to a task."""
        path = '/tasks/%d/addTag' % (task_id)
        return self.client.post(path, params, **options)

    def remove_followers(self, task_id, params={}, **options):
        """Dispatches a POST request to /tasks/:taskId/removeFollowers with to remove followers from the task."""
        path = '/tasks/%d/removeFollowers' % (task_id)
        return self.client.post(path, params, **options)

    def find_all(self, params={}, **options):
        """Returns all tasks that the dispatcher has access to."""
        return self.client.get_collection('/tasks', params, **options)

    def create_in_workspace(self, workspace_id, params={}, **options):
        """Creates a new task in the workspace."""
        path = '/workspaces/%d/tasks' % (workspace_id)
        return self.client.post(path, params, **options)

    def remove_project(self, task_id, params={}, **options):
        """Dispatches a POST request to /tasks/:taskId/removeProject with the project to remove from the task."""
        path = '/tasks/%d/removeProject' % (task_id)
        return self.client.post(path, params, **options)

    def set_parent(self, task_id, params={}, **options):
        """Sets the parent for a task."""
        path = '/tasks/%d/setParent' % (task_id)
        return self.client.post(path, params, **options)

    def projects(self, task_id, params={}, **options):
        """Dispatches a GET request to /tasks/:taskId/projects."""
        path = '/tasks/%d/projects' % (task_id)
        return self.client.get_collection(path, params, **options)

    def delete(self, task_id, params={}, **options):
        """Deletes a task."""
        path = '/tasks/%d' % (task_id)
        return self.client.delete(path, params, **options)
